@@ -1,4 +1,5 @@
 import random
+import string
 
 
 def rand_int(vmin, vmax):
@@ -9,6 +10,20 @@ def rand_double(vmin, vmax):
     return random.uniform(vmin, vmax)
 
 
+def rand_list(len, vmin, vmax, distinct = False):
+    if not distinct:
+        res = []
+        for i in range(0, len):
+            res.append(rand_int(vmin, vmax))
+        return res
+    else:
+        return random.sample(range(vmin, vmax+1), len)
+
+
+def rand_str(length, seed=string.ascii_lowercase):
+    return ''.join(random.choices(seed, k=length))
+
+
 # nhập vào một số nguyên dương duy nhất là số thứ tự của test case, bắt đầu từ 1
 test_number = int(input())
 
