@@ -337,7 +337,8 @@ class TestcaseService:
                 CLog.error(f"Language not supported: `{file_ext}`")
                 os.chdir(owd)
                 return
-            compile_cmd = ["C:\\Program Files\\CodeBlocks\\MinGW\\bin\\g++.exe", "-std=c++14",
+            # C:\\Program Files\\CodeBlocks\\MinGW\\bin\\g++
+            compile_cmd = ["g++.exe", "-std=c++14",
                            file_name,
                            "-pipe", f"-o{file_base_name}.exe"]
             ShellHelper.execute(compile_cmd, timeout=timeout)
